/*  File: analyser-ZpT.cc
 *  Project: Deductor
 *  Created by Zoltán Nagy on 9/8/13.
 *  Modified by D. Soper on 17 December 2013.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/*   local headers  */
#include "analyzer-ZpT.h"



void UserZpT::initfunc()
{
  /*   Creating a histogram to calculate the pT distribution   */
  unsigned nbins = 100;
  double pTmin = 0.0_GeV, pTmax = 100.0_GeV;
  auto bins = spacing<hist1d>::linear(nbins, pTmin, pTmax);
  bool enable_norm = true;
  
  Hist1D::phys(1, "$Z/\\gamma$ $p_T$ distribution", bins, enable_norm);
}


void UserZpT::userfunc(const shower_history<hhc>& history)
{
  /*   Conversion factor from 1/GeV^2 to nb    */
  constexpr double tonb = 389379.338;

  /*   the shower stage after the shower evolution   */
  for(auto& stage : history)
  {
    /*   momentum of the e+e- pair   */
    auto& p = stage.state;
    auto pee = p[-2].momentum + p[-3].momentum;
    
    /*   Filling the histogram   */
    if(pee.perp() < 100.0) {
      weight_type w = weight(stage, tonb);
      
      Hist1D::normfill(1, w[0]);
      Hist1D::physfill(1, w[0], dirac{}, pee.perp());
    }
  }
}



